==> gramps-2%3A5.0.1-2-any.pkg.tar.xz: usr/lib/python3.7/site-packages/gramps/gen/filters/rules/media/_regexpidof.py <==
#
# Gramps - a GTK+/GNOME based genealogy program
#
# Copyright (C) 2002-2006  Donald N. Allingham
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#

#-------------------------------------------------------------------------
#
# Standard Python modules
#
#-------------------------------------------------------------------------
from ....const import GRAMPS_LOCALE as glocale
_ = glocale.translation.gettext

#-------------------------------------------------------------------------
#
# Gramps modules
#
#-------------------------------------------------------------------------
from .._regexpidbase import RegExpIdBase

#-------------------------------------------------------------------------
#
# HasIdOf
#
#-------------------------------------------------------------------------
class RegExpIdOf(RegExpIdBase):
    """
    Rule that checks for a media object whose Gramps ID
    matches regular expression.
    """

    name        = _('Media objects with Id containing <text>')
    description = _("Matches media objects whose Gramps ID matches "
                    "the regular expression")

==> gramps-2%3A5.2.4-1-any.pkg.tar.xz: usr/lib/python3.13/site-packages/gramps/gen/filters/rules/media/_regexpidof.py <==
#
# Gramps - a GTK+/GNOME based genealogy program
#
# Copyright (C) 2002-2006  Donald N. Allingham
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#

# -------------------------------------------------------------------------
#
# Standard Python modules
#
# -------------------------------------------------------------------------
from ....const import GRAMPS_LOCALE as glocale

_ = glocale.translation.gettext

# -------------------------------------------------------------------------
#
# Gramps modules
#
# -------------------------------------------------------------------------
from .._regexpidbase import RegExpIdBase


# -------------------------------------------------------------------------
#
# HasIdOf
#
# -------------------------------------------------------------------------
class RegExpIdOf(RegExpIdBase):
    """
    Rule that checks for a media object whose Gramps ID
    matches regular expression.
    """

    name = _("Media objects with Id containing <text>")
    description = _(
        "Matches media objects whose Gramps ID matches " "the regular expression"
    )
